#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 refinery
version:              0.3.0.0
visibility:           public
id:                   refinery-0.3.0.0-K1s7SzhOzLO7EA6T0AqRfe
key:                  refinery-0.3.0.0-K1s7SzhOzLO7EA6T0AqRfe
license:              BSD-3-Clause
copyright:            2019 Reed Mullanix
maintainer:           reedmullanix@gmail.com
author:               Reed Mullanix
homepage:             https://github.com/totbwf/refinery#readme
synopsis:             Toolkit for building proof automation systems
description:
    Please see the README on GitHub at <https://github.com/githubuser/refinery#readme>

category:             Language
abi:                  3b7cc1faa7901d34ef801e080fcc6078
exposed:              True
exposed-modules:
    Refinery.ProofState Refinery.Tactic Refinery.Tactic.Internal

hidden-modules:       Paths_refinery
import-dirs:          /usr/lib/ghc-8.10.4/site-local/refinery-0.3.0.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/refinery-0.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.4/refinery-0.3.0.0
hs-libraries:         HSrefinery-0.3.0.0-K1s7SzhOzLO7EA6T0AqRfe
depends:
    base-4.14.1.0 exceptions-0.10.4
    logict-0.7.1.0-8TB1GX0GgAW86Tkq1G9jS8
    mmorph-1.1.5-35UKpZuDVOl8bcf8tICns3 mtl-2.2.2

haddock-interfaces:   /usr/share/doc/haskell-refinery/html/refinery.haddock
haddock-html:         /usr/share/doc/haskell-refinery/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

